@@ -1,7 +1,7 @@
 package Business::LegalRepData;
 use strict;
 use warnings;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use URI::Escape;
 use JSON;
@@ -15,6 +15,9 @@ USAGE:
 	my $range_order = $ARGV[0] or die "Must give the argument";
 	my $output_folder = "echrapp_rep_data_extracts";
 	Business::LegalRepData::extract_json_range_number($whole_data_subfolder, $step, $range_order, $output_folder);
+USAGE:
+	my $whole_data_subfolder = "./echrapp_rep_data_extracts";
+	my @cumulative_aoh = Business::LegalRepData::get_aoh_from_range_of_jsons($whole_data_subfolder);	
 =cut
 
 
@@ -152,9 +155,43 @@ sub extract_json_range_number{
 	my $last_file_number  = $file_number_ranges[$range_order-1]->{lst_number};
 	my $json_filename = sprintf "%05d_%05d.json", $first_file_number, $last_file_number;
 	printf "%d => %d. json_filename = %s\n", $first_file_number, $last_file_number, $json_filename ;
-	my $full_json_filename  = $json_filename;
 	my $full_json_filename = File::Spec->catdir($output_folder, $json_filename);
 	read_and_save_rawdata($full_json_filename, $whole_data_subfolder, $first_file_number, $last_file_number);
 }
 
+
+#####################################################################################
+#   READING EXTRACTS
+#####################################################################################
+
+sub get_aoh_from_one_json{
+	my $whole_data_subfolder = shift;
+	my $fn = shift;
+	my $full_file_path = File::Spec->catdir($whole_data_subfolder, $fn);
+	# print  $full_file_path, "\n";
+	open( my $fh, '<', "$full_file_path" ) or die $!;
+	my $json_text = do { local $/; <$fh> };
+	my $perl_scalar = decode_json( $json_text );
+	# print Dumper $perl_scalar;
+	close($fh);
+	# printf "count = %d\n", scalar @$perl_scalar;
+	return @$perl_scalar;
+}
+
+sub get_aoh_from_range_of_jsons{
+	my $whole_data_subfolder = shift;
+	
+    opendir(D, "$whole_data_subfolder") || die "Can't open directory $whole_data_subfolder: $!\n";
+    my @file_list = readdir(D);
+    my @cumulative_aoh;
+    foreach my $f (@file_list) {
+		next if ( -d $f or $f !~ /\.json$/g);
+		my @aoh = get_aoh_from_one_json($whole_data_subfolder, $f);
+		# printf "%d ", scalar @aoh;
+		push @cumulative_aoh, @aoh;
+		# print "$f ";
+	}
+	return @cumulative_aoh;
+}
+
 1;
